@@ -10,6 +10,8 @@ from lxml import etree
 
 from controlled_vocabulary.utils import search_term
 
+import reversion
+
 from ...constants import (
     ABBR_ATTRS, ABSTRACT_ATTRS, ACCESSRESTRICT_ATTRS, ACCRUALS_ATTRS,
     ACQINFO_ATTRS, ADDRESS_ATTRS, ADDRESSLINE_ATTRS, AGENCYCODE_ATTRS,
@@ -157,6 +159,7 @@ class Command(BaseCommand):
             raise CommandError(NOT_WELL_FORMED_XML_MSG.format(path, e))
         ead = tree.getroot()
         try:
+            self.stdout.write('Importing file at {}.'.format(path))
             self._import_ead(ead)
         except Exception as e:
             self.stdout.write('Problem occurred importing file at {}.'.format(
@@ -510,11 +513,13 @@ class Command(BaseCommand):
         except EAD.DoesNotExist:
             pass
         self._record_ids[recordid] = self._path
-        ead_obj = EAD()
-        import_attrs(ead, EAD_ATTRS, ead_obj)
-        self._import_control(ead[0], ead_obj)
-        self._import_archdesc(ead[1], ead_obj)
-        ead_obj.save()
+        with reversion.create_revision():
+            ead_obj = EAD()
+            import_attrs(ead, EAD_ATTRS, ead_obj)
+            self._import_control(ead[0], ead_obj)
+            self._import_archdesc(ead[1], ead_obj)
+            ead_obj.save()
+            reversion.set_comment('Created record from EAD3 XML.')
         return ead_obj
 
     def _import_editionstmt(self, editionstmt, ead_obj):
@@ -738,6 +743,7 @@ class Command(BaseCommand):
             name_obj.save()
             for idx, part in enumerate(name):
                 self._import_part(part, name_obj, part_model, idx)
+            name_obj.save()  # To set the assembled_name from the parts.
         return name_obj
 
     def _import_notestmt(self, notestmt, ead_obj):
@@ -957,6 +963,7 @@ class Command(BaseCommand):
             repository_obj.persnames.add(name_obj)
         for address in xpath(repository, 'e:address'):
             self._import_address(address, repository_obj)
+        repository_obj.save()  # To set the assembled_name from the names.
 
     def _import_representation(self, representation, ead_obj):
         representation_obj = Representation(control=ead_obj)
