@@ -66,6 +66,8 @@ from lxml import etree
 
 from controlled_vocabulary.models import ControlledTermField
 
+import reversion
+
 from .serialisers import EADSerialiser
 from .validators import (
     validate_date_time, validate_id, validate_nmtoken, validate_token)
@@ -476,6 +478,13 @@ class NameMixin(models.Model):
             self.part_set.values_list('plain_name', flat=True))
         super().save(*args, **kwargs)
 
+    def __str__(self):
+        if self.normal:
+            name = self.normal
+        else:
+            name = self.assembled_name
+        return name
+
     class Meta:
         abstract = True
 
@@ -607,7 +616,7 @@ class DAOMixin(CommonMixin, CoverageMixin, EncodingAnalogMixin, LabelMixin,
 
 class EditionStmtSection(models.Model):
     """Corresponds to EAD3 editionstmt."""
-    editionstmt = models.TextField()
+    editionstmt = models.TextField(blank=True)
     editionstmt_altrender = deepcopy(altrender)
     editionstmt_audience = deepcopy(audience)
     editionstmt_encodinganalog = deepcopy(encodinganalog)
@@ -724,7 +733,7 @@ class MaintenanceSection(models.Model):
     agencycode_localtype = deepcopy(localtype)
     agencycode_script = deepcopy(script)
     agencycode = models.CharField(blank=True, max_length=32)
-    maintenanceagency_descriptivenote = models.TextField()
+    maintenanceagency_descriptivenote = models.TextField(blank=True)
     maintenanceagency_descriptivenote_altrender = deepcopy(altrender)
     maintenanceagency_descriptivenote_audience = deepcopy(audience)
     maintenanceagency_descriptivenote_encodinganalog = deepcopy(encodinganalog)
@@ -804,6 +813,9 @@ class SourcesSection(models.Model):
     sources_localtype = deepcopy(localtype)
     sources_script = deepcopy(script)
 
+    class Meta:
+        abstract = True
+
 
 class ControlSection(FileDescSection, MaintenanceSection,
                      PublicationStatusSection, RecordIdSection,
@@ -882,8 +894,6 @@ class DIdSection(models.Model):
     did_head_ead_id = deepcopy(ead_id)
     did_head_lang = deepcopy(lang)
     did_head_script = deepcopy(script)
-    repositories = models.ManyToManyField(
-        'Repository', help_text=constants.REPOSITORY_HELP)
 
     class Meta:
         abstract = True
@@ -947,6 +957,22 @@ class ArchDescSection(DIdSection, RelationsSection):
         abstract = True
 
 
+@reversion.register(follow=[
+    'abstract_set', 'accessrestrict_set', 'accruals_set', 'acqinfo_set',
+    'agencyname_set', 'altformavail_set', 'appraisal_set', 'arrangement_set',
+    'author_set', 'bibliography_set', 'bioghist_set', 'container_set',
+    'controlaccess_set', 'controlnote_set', 'conventiondeclaration_set',
+    'custodhist_set', 'dao_set', 'daoset_set', 'didnote_set', 'fileplan_set',
+    'index_set', 'langmaterial_set', 'legalstatus_set', 'localcontrol_set',
+    'localtypedeclaration_set', 'maintenanceevent_set', 'materialspec_set',
+    'odd_set', 'originalsloc_set', 'origination_set', 'otheragencycode_set',
+    'otherfindaid_set', 'otherrecordid_set', 'physdesc_set', 'physdescset_set',
+    'physdescstructured_set', 'physloc_set', 'phystech_set', 'prefercite_set',
+    'processinfo_set', 'relatedmaterial_set', 'relation_set',
+    'representation_set', 'rightsdeclaration_set', 'scopecontent_set',
+    'separatedmaterial_set', 'source_set', 'sponsor_set', 'subtitle_set',
+    'titleproper_set', 'unitdate_set', 'unitdatestructured_set', 'unitid_set',
+    'unittitle_set', 'userestrict_set'])
 class EAD(BaseMixin, CommonMixin, LangScriptMixin, RelatedEncodingMixin,
           ControlSection, ArchDescSection):
     # In order to avoid as many levels of joins as we can without
@@ -961,7 +987,10 @@ class EAD(BaseMixin, CommonMixin, LangScriptMixin, RelatedEncodingMixin,
     # Some fields that properly belong in one of the *Section abstract
     # models are defined here in order to avoid having to specify a
     # cumbersome related_name.
-    languagedeclarations = models.ManyToManyField('LanguageDeclaration')
+    languagedeclarations = models.ManyToManyField(
+        'LanguageDeclaration', blank=True)
+    repositories = models.ManyToManyField(
+        'Repository', blank=True, help_text=constants.REPOSITORY_HELP)
 
     def serialise(self):
         """Return this object (and its related objects) serialised as a
@@ -973,6 +1002,10 @@ class EAD(BaseMixin, CommonMixin, LangScriptMixin, RelatedEncodingMixin,
         serialiser = EADSerialiser()
         return serialiser.serialise(self)
 
+    def __str__(self):
+        unittitles = self.unittitle_set.values_list('unittitle', flat=True)
+        return ' - '.join(unittitles)
+
     def to_xml(self):
         """Return this object (and its related objects) as an EAD3 XML
         document.
@@ -984,6 +1017,7 @@ class EAD(BaseMixin, CommonMixin, LangScriptMixin, RelatedEncodingMixin,
         return serialiser.to_xml(self)
 
 
+@reversion.register()
 class Abstract(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 abstract."""
@@ -991,6 +1025,7 @@ class Abstract(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     abstract = models.TextField()
 
 
+@reversion.register()
 class AccessRestrict(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                      LocalTypeMixin):
     """Corresponds to EAD3 accessrestrict."""
@@ -998,6 +1033,7 @@ class AccessRestrict(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     accessrestrict = models.TextField()
 
 
+@reversion.register()
 class Accruals(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 accruals."""
@@ -1005,6 +1041,7 @@ class Accruals(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     accruals = models.TextField()
 
 
+@reversion.register()
 class AcqInfo(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
               LocalTypeMixin):
     """Corresponds to EAD3 acqinfo."""
@@ -1012,6 +1049,7 @@ class AcqInfo(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     acqinfo = models.TextField()
 
 
+@reversion.register()
 class AgencyName(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                  LocalTypeMixin):
     """Corresponds to EAD3 agencyname."""
@@ -1019,6 +1057,7 @@ class AgencyName(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     agencyname = models.TextField()
 
 
+@reversion.register()
 class AltFormAvail(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 altformavail."""
@@ -1026,6 +1065,7 @@ class AltFormAvail(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     altformavail = models.TextField()
 
 
+@reversion.register()
 class Appraisal(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                 LocalTypeMixin):
     """Corresponds to EAD3 appraisal."""
@@ -1033,6 +1073,7 @@ class Appraisal(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     appraisal = models.TextField()
 
 
+@reversion.register()
 class Arrangement(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 arrangement."""
@@ -1040,6 +1081,7 @@ class Arrangement(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     arrangement = models.TextField()
 
 
+@reversion.register()
 class Author(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
              LocalTypeMixin):
     """Corresponds to EAD3 author."""
@@ -1047,6 +1089,7 @@ class Author(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     author = models.TextField()
 
 
+@reversion.register()
 class Bibliography(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 bibliography."""
@@ -1054,6 +1097,7 @@ class Bibliography(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     bibliography = models.TextField()
 
 
+@reversion.register()
 class BiogHist(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 bioghist."""
@@ -1061,6 +1105,7 @@ class BiogHist(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     bioghist = models.TextField()
 
 
+@reversion.register()
 class Container(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                 LocalTypeMixin):
     """Corresponds to EAD3 container."""
@@ -1071,6 +1116,7 @@ class Container(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
         'self', related_name='child_containers', symmetrical=False)
 
 
+@reversion.register()
 class ControlAccess(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                     LocalTypeMixin):
     """Corresponds to EAD3 controlaccess."""
@@ -1078,6 +1124,7 @@ class ControlAccess(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     controlaccess = models.TextField()
 
 
+@reversion.register()
 class ControlNote(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 controlnote.
@@ -1091,6 +1138,7 @@ class ControlNote(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     controlnote = models.TextField()
 
 
+@reversion.register()
 class ConventionDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                             LocalTypeMixin, AbbrMixin, CitationMixin,
                             DescriptiveNoteMixin):
@@ -1098,6 +1146,7 @@ class ConventionDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     control = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register(follow=['part_set'])
 class CorpName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin, NormalMixin, RelatorMixin, NameMixin):
     """Corresponds to EAD3 corpname.
@@ -1109,6 +1158,7 @@ class CorpName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     pass
 
 
+@reversion.register()
 class CorpNamePart(PartMixin):
     """Corresponds to EAD3 part as a child of corpname."""
     name = models.ForeignKey(
@@ -1119,6 +1169,7 @@ class CorpNamePart(PartMixin):
         unique_together = ['name', 'order']
 
 
+@reversion.register()
 class CustodHist(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                  LocalTypeMixin):
     """Corresponds to EAD3 custodhist."""
@@ -1126,12 +1177,14 @@ class CustodHist(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     custodhist = models.TextField()
 
 
+@reversion.register()
 class DIdDAO(DAOMixin):
     """Corresponds to EAD3 dao as a child of did."""
     parent = models.ForeignKey(
         EAD, on_delete=models.CASCADE, related_name='dao_set')
 
 
+@reversion.register()
 class DIdNote(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
               LocalTypeMixin):
     """Corresponds to EAD3 didnote."""
@@ -1139,12 +1192,14 @@ class DIdNote(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     didnote = models.TextField()
 
 
+@reversion.register(follow=['dimensions_set', 'physfacet_set'])
 class DIdPhysDescStructured(PhysDescStructuredMixin):
     """Corresponds to EAD3 physdescstrutured as a child of did."""
     parent = models.ForeignKey(
         EAD, on_delete=models.CASCADE, related_name='physdescstructured_set')
 
 
+@reversion.register()
 class DIdPhysDescStructuredDimensions(DimensionsMixin):
     """Corresponds to EAD3 dimensions as a grandchild of did."""
     physdescstructured = models.ForeignKey(
@@ -1152,6 +1207,7 @@ class DIdPhysDescStructuredDimensions(DimensionsMixin):
         related_name='dimensions_set')
 
 
+@reversion.register()
 class DIdPhysDescStructuredPhysFacet(PhysFacetMixin):
     """Corresponds to EAD3 physfacet as a grandchild of did"""
     physdescstructured = models.ForeignKey(
@@ -1159,6 +1215,7 @@ class DIdPhysDescStructuredPhysFacet(PhysFacetMixin):
         related_name='physfacet_set')
 
 
+@reversion.register(follow=['dao_set'])
 class DAOSet(BaseMixin, CommonMixin, CoverageMixin, EncodingAnalogMixin,
              LabelMixin, LangScriptMixin, LocalTypeMixin,
              DescriptiveNoteMixin):
@@ -1166,12 +1223,14 @@ class DAOSet(BaseMixin, CommonMixin, CoverageMixin, EncodingAnalogMixin,
     did = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register()
 class DAOSetDAO(DAOMixin):
     """Corresponds to EAD3 dao as a child of daoset."""
     parent = models.ForeignKey(
         DAOSet, on_delete=models.CASCADE, related_name='dao_set')
 
 
+@reversion.register()
 class EventDescription(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                        LocalTypeMixin):
     """Corresponds to EAD3 eventdescription."""
@@ -1180,6 +1239,7 @@ class EventDescription(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     eventdescription = models.TextField()
 
 
+@reversion.register(follow=['part_set'])
 class FamName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
               LocalTypeMixin, NormalMixin, RelatorMixin, NameMixin):
     """Corresponds to EAD3 famname.
@@ -1191,6 +1251,7 @@ class FamName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     pass
 
 
+@reversion.register()
 class FamNamePart(PartMixin):
     """Corresponds to EAD3 part as a child of famname."""
     name = models.ForeignKey(
@@ -1201,6 +1262,7 @@ class FamNamePart(PartMixin):
         unique_together = ['name', 'order']
 
 
+@reversion.register()
 class FilePlan(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 fileplan."""
@@ -1208,6 +1270,7 @@ class FilePlan(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     fileplan = models.TextField()
 
 
+@reversion.register()
 class Index(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
             LocalTypeMixin):
     """Corresponds to EAD3 index."""
@@ -1215,12 +1278,14 @@ class Index(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     index = models.TextField()
 
 
+@reversion.register(follow=['language_set', 'languageset_set'])
 class LangMaterial(CommonMixin, EncodingAnalogMixin, LabelMixin,
                    LangScriptMixin, DescriptiveNoteMixin):
     """Corresponds to EAD3 langmaterial."""
     did = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register()
 class LangMaterialLanguage(CommonMixin, EncodingAnalogMixin, LabelMixin,
                            LangScriptMixin, LanguageMixin):
     """Corresponds to EAD3 language as a child of langmaterial."""
@@ -1229,6 +1294,7 @@ class LangMaterialLanguage(CommonMixin, EncodingAnalogMixin, LabelMixin,
     langcode = deepcopy(lang)
 
 
+@reversion.register()
 class LanguageDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                           DescriptiveNoteMixin, LanguageMixin, ScriptMixin):
     """Corresponds to EAD3 languagedeclaration.
@@ -1256,12 +1322,14 @@ class LanguageDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     script_el_script = deepcopy(script)
 
 
+@reversion.register(follow=['language_set', 'script_set'])
 class LanguageSet(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   DescriptiveNoteMixin):
     """Corresponds to EAD3 languageset."""
     langmaterial = models.ForeignKey(LangMaterial, on_delete=models.CASCADE)
 
 
+@reversion.register()
 class LanguageSetLanguage(CommonMixin, EncodingAnalogMixin, LabelMixin,
                           LangScriptMixin, LanguageMixin):
     """Corresponds to EAD3 language as a child of languageset."""
@@ -1270,6 +1338,7 @@ class LanguageSetLanguage(CommonMixin, EncodingAnalogMixin, LabelMixin,
     langcode = deepcopy(lang)
 
 
+@reversion.register()
 class LanguageSetScript(CommonMixin, EncodingAnalogMixin, LabelMixin,
                         LangScriptMixin, ScriptMixin):
     """Corresponds to EAD3 script as a child of languageset."""
@@ -1278,6 +1347,7 @@ class LanguageSetScript(CommonMixin, EncodingAnalogMixin, LabelMixin,
     scriptcode = deepcopy(script)
 
 
+@reversion.register()
 class LegalStatus(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 legalstatus."""
@@ -1285,6 +1355,7 @@ class LegalStatus(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     legalstatus = models.TextField()
 
 
+@reversion.register()
 class LocalControl(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 localcontrol."""
@@ -1339,12 +1410,14 @@ class LocalControl(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     datesingle_standarddate = deepcopy(standarddate)
 
 
+@reversion.register()
 class LocalTypeDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                            AbbrMixin, CitationMixin, DescriptiveNoteMixin):
     """Corresponds to EAD3 localtypedeclaration."""
     control = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register(follow=['eventdescription_set'])
 class MaintenanceEvent(CommonMixin, EncodingAnalogMixin, LangScriptMixin):
     """Corresponds to EAD3 maintenanceevent and its descendants."""
     AGENT_TYPE_HUMAN = 'human'
@@ -1408,6 +1481,7 @@ class MaintenanceEvent(CommonMixin, EncodingAnalogMixin, LangScriptMixin):
     eventtype = models.CharField(blank=True, max_length=32)
 
 
+@reversion.register()
 class MaterialSpec(CommonMixin, EncodingAnalogMixin, LabelMixin,
                    LangScriptMixin, LocalTypeMixin):
     """Corresponds to EAD3 materialspec."""
@@ -1415,6 +1489,7 @@ class MaterialSpec(CommonMixin, EncodingAnalogMixin, LabelMixin,
     materialspec = models.TextField()
 
 
+@reversion.register(follow=['part_set'])
 class Name(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
            LocalTypeMixin, NormalMixin, RelatorMixin, NameMixin):
     """Corresponds to EAD3 name.
@@ -1426,6 +1501,7 @@ class Name(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     pass
 
 
+@reversion.register()
 class NamePart(PartMixin):
     """Corresponds to EAD3 part as a child of name."""
     name = models.ForeignKey(
@@ -1436,6 +1512,7 @@ class NamePart(PartMixin):
         unique_together = ['name', 'order']
 
 
+@reversion.register()
 class ODD(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
           LocalTypeMixin):
     """Corresponds to EAD3 odd."""
@@ -1443,6 +1520,7 @@ class ODD(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     odd = models.TextField()
 
 
+@reversion.register()
 class OriginalsLoc(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 originalsloc."""
@@ -1450,17 +1528,18 @@ class OriginalsLoc(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     originalsloc = models.TextField()
 
 
+@reversion.register()
 class Origination(CommonMixin, EncodingAnalogMixin, LabelMixin,
                   LangScriptMixin, LocalTypeMixin):
     """Corresponds to EAD3 origination."""
     did = models.ForeignKey(EAD, on_delete=models.CASCADE)
-    origination = models.TextField()
     corpnames = models.ManyToManyField(CorpName)
     famnames = models.ManyToManyField(FamName)
     names = models.ManyToManyField(Name)
     persnames = models.ManyToManyField('PersName')
 
 
+@reversion.register()
 class OtherAgencyCode(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                       LocalTypeMixin):
     """Corresponds to EAD3 otheragencycode."""
@@ -1468,6 +1547,7 @@ class OtherAgencyCode(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     otheragencycode = models.CharField(max_length=32)
 
 
+@reversion.register()
 class OtherFindAid(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 otherfindaid."""
@@ -1475,6 +1555,7 @@ class OtherFindAid(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     otherfindaid = models.TextField()
 
 
+@reversion.register()
 class OtherRecordID(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                     LocalTypeMixin):
     """Corresponds to EAD3 otherrecordid."""
@@ -1482,6 +1563,7 @@ class OtherRecordID(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     otherrecordid = models.CharField(max_length=512)
 
 
+@reversion.register(follow=['part_set'])
 class PersName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin, NormalMixin, RelatorMixin, NameMixin):
     """Corresponds to EAD3 pername.
@@ -1493,6 +1575,7 @@ class PersName(AccessMixin, CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     pass
 
 
+@reversion.register()
 class PersNamePart(PartMixin):
     """Corresponds to EAD3 part as a child of persname."""
     name = models.ForeignKey(
@@ -1503,6 +1586,7 @@ class PersNamePart(PartMixin):
         unique_together = ['name', 'order']
 
 
+@reversion.register()
 class PhysDesc(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 physdesc."""
@@ -1510,6 +1594,7 @@ class PhysDesc(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     physdesc = models.TextField()
 
 
+@reversion.register(follow=['physdescstructured_set'])
 class PhysDescSet(CommonMixin, CoverageMixin, EncodingAnalogMixin, LabelMixin,
                   LangScriptMixin, DescriptiveNoteMixin):
     """Corresponds to EAD3 physdescset."""
@@ -1517,6 +1602,7 @@ class PhysDescSet(CommonMixin, CoverageMixin, EncodingAnalogMixin, LabelMixin,
     parallel = models.BooleanField(null=True)
 
 
+@reversion.register(follow=['dimensions_set', 'physfacet_set'])
 class PhysDescSetPhysDescStructured(PhysDescStructuredMixin):
     """Corresponds to EAD3 physdescstructured as a child of physdescset."""
     parent = models.ForeignKey(
@@ -1524,6 +1610,7 @@ class PhysDescSetPhysDescStructured(PhysDescStructuredMixin):
         related_name='physdescstructured_set')
 
 
+@reversion.register()
 class PhysDescSetPhyDescStructuredDimensions(DimensionsMixin):
     """Corresponds to EAD3 dimensions as a grandchild of physdescset."""
     physdescstructured = models.ForeignKey(
@@ -1531,6 +1618,7 @@ class PhysDescSetPhyDescStructuredDimensions(DimensionsMixin):
         related_name='dimensions_set')
 
 
+@reversion.register()
 class PhysDescSetPhysDescStructuredPhysFacet(PhysFacetMixin):
     """Corresponds to EAD3 physfacet as a grandchild of physdescset."""
     physdescstructured = models.ForeignKey(
@@ -1538,6 +1626,7 @@ class PhysDescSetPhysDescStructuredPhysFacet(PhysFacetMixin):
         related_name='physfacet_set')
 
 
+@reversion.register()
 class PhysLoc(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
               LocalTypeMixin):
     """Corresponds to EAD3 physloc."""
@@ -1547,6 +1636,7 @@ class PhysLoc(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     physloc = models.TextField()
 
 
+@reversion.register()
 class PhysTech(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 phystech."""
@@ -1554,6 +1644,7 @@ class PhysTech(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     phystech = models.TextField()
 
 
+@reversion.register()
 class PreferCite(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                  LocalTypeMixin):
     """Corresponds to EAD3 prefercite."""
@@ -1561,6 +1652,7 @@ class PreferCite(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     prefercite = models.TextField()
 
 
+@reversion.register()
 class ProcessInfo(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 processinfo."""
@@ -1568,6 +1660,7 @@ class ProcessInfo(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     processinfo = models.TextField()
 
 
+@reversion.register()
 class RelatedMaterial(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                       LocalTypeMixin):
     """Corresponds to EAD3 relatedmaterial."""
@@ -1575,6 +1668,8 @@ class RelatedMaterial(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     relatedmaterial = models.TextField()
 
 
+@reversion.register(follow=['daterange_set', 'datesingle_set',
+                            'relationentry_set'])
 class Relation(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LinkMixin, DateSetMixin, DescriptiveNoteMixin,
                ObjectXMLWrapMixin):
@@ -1610,18 +1705,21 @@ class Relation(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     geogname = models.TextField(blank=True)
 
 
+@reversion.register()
 class RelationDateRange(DateRangeMixin):
     """Corresponds to EAD3 daterange as a child of relation."""
     parent = models.ForeignKey(
         Relation, on_delete=models.CASCADE, related_name='daterange_set')
 
 
+@reversion.register()
 class RelationDateSingle(DateSingleMixin):
     """Corresponds to EAD3 datesingle as a child of relation."""
     parent = models.ForeignKey(
         Relation, on_delete=models.CASCADE, related_name='datesingle_set')
 
 
+@reversion.register()
 class RelationEntry(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                     LocalTypeMixin, TransliterationMixin):
     """Corresponds to EAD3 relationentry."""
@@ -1629,6 +1727,7 @@ class RelationEntry(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     relationentry = models.TextField()
 
 
+@reversion.register(follow=['addressline_set'])
 class Repository(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                  LocalTypeMixin):
     """Corresponds to EAD3 repository."""
@@ -1656,10 +1755,14 @@ class Repository(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                 'assembled_name', flat=True))
             name_parts.extend(
                 self.persnames.values_list('assembled_name', flat=True))
-            self.assembled_name = ''.join(name_parts)
+            self.assembled_name = '; '.join(name_parts)
         super().save(*args, **kwargs)
 
+    def __str__(self):
+        return self.assembled_name
 
+
+@reversion.register()
 class RepositoryAddressLine(CommonMixin, LangScriptMixin, LocalTypeMixin):
     """Corresponds to EAD3 addressline as a grandchild of repository."""
     address = models.ForeignKey(
@@ -1667,6 +1770,7 @@ class RepositoryAddressLine(CommonMixin, LangScriptMixin, LocalTypeMixin):
     addressline = models.TextField()
 
 
+@reversion.register()
 class Representation(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                      LinkMixin, LocalTypeMixin):
     """Corresponds to EAD3 representation."""
@@ -1674,6 +1778,7 @@ class Representation(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     representation = models.TextField(blank=True)
 
 
+@reversion.register()
 class RightsDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                         LocalTypeMixin, AbbrMixin, CitationMixin,
                         DescriptiveNoteMixin):
@@ -1681,6 +1786,7 @@ class RightsDeclaration(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     control = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register()
 class ScopeContent(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                    LocalTypeMixin):
     """Corresponds to EAD3 scopecontent."""
@@ -1688,6 +1794,7 @@ class ScopeContent(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     scopecontent = models.TextField()
 
 
+@reversion.register()
 class SeparatedMaterial(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                         LocalTypeMixin):
     """Corresponds to EAD3 separatedmaterial."""
@@ -1695,6 +1802,7 @@ class SeparatedMaterial(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     separatedmaterial = models.TextField()
 
 
+@reversion.register(follow=['sourceentry_set'])
 class Source(CommonMixin, EncodingAnalogMixin, LangScriptMixin, LinkMixin,
              DescriptiveNoteMixin, ObjectXMLWrapMixin):
     """Corresponds to EAD3 source."""
@@ -1702,6 +1810,7 @@ class Source(CommonMixin, EncodingAnalogMixin, LangScriptMixin, LinkMixin,
     lastdatetimeverified = deepcopy(lastdatetimeverified)
 
 
+@reversion.register()
 class SourceEntry(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   TransliterationMixin):
     """Corresponds to EAD3 sourceentry."""
@@ -1709,6 +1818,7 @@ class SourceEntry(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     sourceentry = models.TextField()
 
 
+@reversion.register()
 class Sponsor(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
               LocalTypeMixin):
     """Corresponds to EAD3 sponsor."""
@@ -1716,6 +1826,7 @@ class Sponsor(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     sponsor = models.TextField()
 
 
+@reversion.register()
 class Subtitle(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                LocalTypeMixin):
     """Corresponds to EAD3 subtitle."""
@@ -1723,6 +1834,7 @@ class Subtitle(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     subtitle = models.TextField()
 
 
+@reversion.register()
 class TitleProper(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 titleproper as a child of titlestmt.
@@ -1743,7 +1855,7 @@ class TitleProper(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
     RENDER_ITALIC = 'italic'
     RENDER_NONPROPORT = 'nonproport'
     RENDER_SINGLEQUOTE = 'singlequote'
-    RENDER_SMCAPS ='smcaps'
+    RENDER_SMCAPS = 'smcaps'
     RENDER_SUB = 'sub'
     RENDER_SUPER = 'super'
     RENDER_UNDERLINE = 'underline'
@@ -1764,13 +1876,13 @@ class TitleProper(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
         (RENDER_SUPER, 'Superscript'),
         (RENDER_UNDERLINE, 'Underline'),
     ]
-    titlestmt = models.ForeignKey(
-        EAD, on_delete=models.CASCADE, related_name='titleproper_set')
+    titlestmt = models.ForeignKey(EAD, on_delete=models.CASCADE)
     titleproper = models.TextField()
     render = models.CharField(
         blank=True, choices=RENDER_CHOICES, max_length=15)
 
 
+@reversion.register()
 class UnitDate(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                NormalMixin, UnitDateAttrMixin):
     """Corresponds to EAD3 unitdate."""
@@ -1778,12 +1890,14 @@ class UnitDate(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     unitdate = models.TextField()
 
 
+@reversion.register(follow=['daterange_set', 'datesingle_set'])
 class UnitDateStructured(CommonMixin, EncodingAnalogMixin, LabelMixin,
                          LangScriptMixin, UnitDateAttrMixin, DateSetMixin):
     """Corresponds to EAD3 unitdatestructured."""
     did = models.ForeignKey(EAD, on_delete=models.CASCADE)
 
 
+@reversion.register()
 class UnitDateStructuredDateRange(DateRangeMixin):
     """Corresponds to EAD3 daterange as a child or grandchild (within
     dateset) of unitdatestructured."""
@@ -1792,6 +1906,7 @@ class UnitDateStructuredDateRange(DateRangeMixin):
         related_name='daterange_set')
 
 
+@reversion.register()
 class UnitDateStructuredDateSingle(DateSingleMixin):
     """Corresponds to EAD3 datesingle as a child or grandchild (within
     dateset) of unitdatestructured."""
@@ -1800,6 +1915,7 @@ class UnitDateStructuredDateSingle(DateSingleMixin):
         related_name='datesingle_set')
 
 
+@reversion.register()
 class UnitId(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
              LocalTypeMixin):
     """Corresponds to EAD3 unitid."""
@@ -1811,6 +1927,7 @@ class UnitId(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
         blank=True, max_length=32, validators=[validate_token])
 
 
+@reversion.register()
 class UnitTitle(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
                 LocalTypeMixin, NormalMixin):
     """Corresponds to EAD3 unittitle."""
@@ -1818,6 +1935,7 @@ class UnitTitle(CommonMixin, EncodingAnalogMixin, LabelMixin, LangScriptMixin,
     unittitle = models.TextField()
 
 
+@reversion.register()
 class UseRestrict(CommonMixin, EncodingAnalogMixin, LangScriptMixin,
                   LocalTypeMixin):
     """Corresponds to EAD3 userestrict."""
